#[non_exhaustive]pub struct ClientKeyboardInteractiveInfo {
pub name: String,
pub instructions: String,
/* private fields */
}Expand description
Information about a keyboard-interactive authentication prompt.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name describing the authentication step.
instructions: StringInstructions for the user (may be empty).
Implementations
Sourceimpl ClientKeyboardInteractiveInfo
impl ClientKeyboardInteractiveInfo
Sourcepub fn new(
name: String,
instructions: String,
prompts: Vec<ClientKeyboardInteractivePrompt>,
) -> Self
pub fn new( name: String, instructions: String, prompts: Vec<ClientKeyboardInteractivePrompt>, ) -> Self
Creates a new info request from the given fields.
This constructor is intended for wrapping raw russh keyboard-interactive info requests.
Sourcepub fn prompts(&self) -> &[ClientKeyboardInteractivePrompt]
pub fn prompts(&self) -> &[ClientKeyboardInteractivePrompt]
Returns the prompts in this keyboard-interactive challenge.